# ProteusISC

Linux USB JTAG controller for Digilent boards.

To see hardware reverse engineering notes, visit http://diamondman.github.io/Adapt/.

## Installation / Setup

   sudo pip install .

For additional information on setting up supported jtag controllers, check the documentation link above..

## Testing

    pytest --cov-report term-missing --cov proteusisc -v

## Installation while developing

    pip install . -U --no-deps